@@ -80,7 +80,7 @@ class TestUserEndpoint:
     @pytest.fixture(autouse=True)
     def setup_attrs(self, configured_app) -> None:
         self.app = configured_app
-        self.client = self.app.test_client()  # type:ignore
+        self.client = self.app.test_client()
         self.session = self.app.appbuilder.get_session
 
     def teardown_method(self) -> None:
